==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_front/app/controllers/common_controller.rb <==
# -*- coding: utf-8 -*-
class CommonController < PcController

  # = 商品詳細画面にchow_cart_inを表示します =
  def show_cart_in
    @product_sku = ProductSku.find_by_sku_code(params[:sku_code])
    render(:partial => 'cms/show_cart_in')
  end

  #
  # = 国を変更します =
  #
  def change_country
    address_form = UserAddress.new(params[:address_form])
    sub_address = UserAddress.hash_to_sub_address(params[:sub_address])
    sub_address ||= UserAddress.new()

    local_options = {:form_name => params[:form_name], :user_address => params[:user_address],
      :address_form => address_form, :sub_address => sub_address, :shippable_to_oversea => params[:shippable_to_oversea]}

    if address_form.country_code == 'JP' && I18n.locale.to_s == 'ja'
      render(:partial => 'shared/name_address_jp', :locals => local_options)
    else
      render(:partial => 'shared/name_address_i18n', :locals => local_options)
    end
  end

  # developmentモードでは自動的にerbはリロードされるので、productionモードのときだけ
  # テンプレートの再読み込みを行います。
  # ただし、developmentモードでは、ファイルの追加を検知できないので、そのような場合は
  # サーバーを再起動する必要があります。
  def update_views
    if RAILS_ENV == 'production'
      view_methods = (ActionView::Base::CompiledTemplates.instance_methods.sort - Object.methods).
        select{|method_name| method_name =~ /_run_erb_app47views47/}
      ActionView::Base::CompiledTemplates.module_eval do
        view_methods.each do |method_name|
          puts "ActionView::Base::CompiledTemplates.remove_method(#{method_name})"
          remove_method(method_name)
        end
      end
      # インスタンスを作り直すので、こちらの方法は取らないようにします。
      # ActionController::Base.view_paths = [File.expand_path(File.join(RAILS_ROOT, 'app/views'))]
      ActionController::Base.view_paths.each do |path|
        path.instance_variable_set(:@loaded, false)
        path.instance_variable_set(:@paths, nil)
        path.load!
      end
      # ActionController::Base.view_paths.load! # 各pathでload!してるので不要
      # ActionMailer::Base.view_paths.load!
    end
    render(:text => "OK!", :layout => false)
  end

  def to_address
    address = JpAddress.find_by_zipcode params[:id]
    if address
      logger.debug "[#{address.prefecture}','#{address.city}','#{address.address}']"
      render :text => "['#{address.prefecture}','#{address.city}','#{address.address}']"
    else
      render :text => "['','','']"
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_front/app/controllers/common_controller.rb <==
# -*- coding: utf-8 -*-
class CommonController < ApplicationController
  include EcRider::SetDefaultLayout

  # = 商品詳細画面にchow_cart_inを表示します =
  def show_cart_in
    @product_sku = ProductSku.find_by_sku_code(params[:sku_code])
    render(:partial => 'cms/show_cart_in')
  end

  #
  # = 国を変更します =
  #
  def change_country
    address_form = UserAddress.new(params[:address_form])
    sub_address = UserAddress.hash_to_sub_address(params[:sub_address])
    sub_address ||= UserAddress.new()

    local_options = {:form_name => params[:form_name], :user_address => params[:user_address],
      :address_form => address_form, :sub_address => sub_address, :shippable_to_oversea => params[:shippable_to_oversea]}

    if address_form.country_code == 'JP' && I18n.locale.to_s == 'ja'
      render(:partial => 'shared/name_address_jp', :locals => local_options)
    else
      render(:partial => 'shared/name_address_i18n', :locals => local_options)
    end
  end

  # developmentモードでは自動的にerbはリロードされるので、productionモードのときだけ
  # テンプレートの再読み込みを行います。
  # ただし、developmentモードでは、ファイルの追加を検知できないので、そのような場合は
  # サーバーを再起動する必要があります。
  # ※ passengerのように各プロセスがTCPポートをListenしていない場合は、
  #    CommonController#update_views_for_passengerを使用してください。
  def update_views
    EcRider::ViewCacheCtrl.view_cache_clear if RAILS_ENV == 'production'
    render(:text => "OK!", :layout => false)
  end

  # テンプレートの再読み込みを行います。
  # ※ mongrelのように各プロセス毎にTCPポートをListenしている場合は、
  #    CommonController#update_viewsを使用してください。
  def update_views_for_passenger
    EcRider::ViewCacheCtrl.remove_and_create_published_date if RAILS_ENV == 'production'
    render(:text => "OK!", :layout => false)
  end

  def to_address
    address = JpAddress.find_by_zipcode params[:id]
    if address
      logger.debug "[#{address.prefecture}','#{address.city}','#{address.address}']"
      render :text => "['#{address.prefecture}','#{address.city}','#{address.address}']"
    else
      render :text => "['','','']"
    end
  end
end
